==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=br
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_message_forum' => 'Kemenadenn forom ebet',

	// B
	'bouton_radio_articles_futurs' => 'er pennadoù da zont hepken (oberiadenn ebet en diaz titouroù)',
	'bouton_radio_articles_tous' => 'en holl pennadoù.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'en holl bennadoù n’eo ket bet diweredekaet o forom',
	'bouton_radio_enregistrement_obligatoire' => 'Enrolladenn ret (a-raok gallout kemer perzh e rank an implijerien en em enrollañ en ur reiñ o chomlec’h postel).',
	'bouton_radio_moderation_priori' => 'Gwiriañ a-raok embann (diskouez a reer ar c’hemennadennoù ur wech lennet hag aotreet gant ar verourien hepken).',
	'bouton_radio_modere_abonnement' => 'war goumanant',
	'bouton_radio_modere_posteriori' => 'gwiriañ goude an embann',
	'bouton_radio_modere_priori' => 'gwiriañ a-raok embann',
	'bouton_radio_publication_immediate' => 'Embann ar c’hemennadennoù kerkent (embannet e vez ar c’hemennadennoù diouzhtu goude bezañ bet skrivet, war-lerc’h e c’hellont bezañ diverket gant ar verourien).',

	// D
	'documents_interdits_forum' => 'Teulioù difennet er forom',

	// E
	'erreur_enregistrement_message' => 'Ne ket bet posubl enrolliñ ho kemenadenn ablamour d’un diaesamant teknikel',
	'extensions_autorisees' => 'Astennoù aotreet',
	'extensions_autorisees_toutes' => 'holl',

	// F
	'form_pet_message_commentaire' => 'Ur gemennadenn, un evezhiadenn ?',
	'forum' => 'Forom',
	'forum_acces_refuse' => 'N’oc’h ket aotreet da vont war ar foromoù-mañ ken .',
	'forum_attention_dix_caracteres' => '<b>Diwallit !</b> Dek arouezenn d’an nebeutañ a rank bezañ en ho kemennadenn.',
	'forum_attention_message_non_poste' => 'Taolit evezh, n’ho peus ket kaset ho kemenadenn !',
	'forum_attention_nb_caracteres_mini' => '<b>Taolit evezh !</b> ho kemenadenn a rank bezañ henni @min@ letrenn.',
	'forum_attention_trois_caracteres' => '<b>Diwallit !</b> Teir arouezenn d’an nebeutañ a rank bezañ en ho titl.',
	'forum_attention_trop_caracteres' => '<b>Diwallit !</b> re hir eo ho kemennadenn (@compte@ arouez) : arabat e vefe ouzhpenn @max@ arouezenn enni evit gallout bezañ kaset.',
	'forum_avez_selectionne' => 'Diuzet hoc’h eus :',
	'forum_cliquer_retour' => 'Klikit <a href=\'@retour_forum@\'>amañ</a> evit kenderc’hel.',
	'forum_envoyer' => 'Kas',
	'forum_forum' => 'forom',
	'forum_info_modere' => 'Habaskaet eo ar forom-mañ a-raok embann ar pennadoù : ne vo ket gwelet ho kemennadenn a-raok na vefe lennet hag asantet gant unan eus merourien al lec’hienn.',
	'forum_lien_hyper' => '<b>liamm gourskrid</b> (Diret)',
	'forum_message' => 'Ho kemenadenn',
	'forum_message_definitif' => 'Kemennadenn echu : kas d’al lec’hienn',
	'forum_message_trop_long' => 'Re hir eo ho kemennadenn. 20000 arouezenn a c’heller lakaat d’ar muiañ.',
	'forum_ne_repondez_pas' => 'Na respontit ket d’ar postel-mañ, met war ar forom, d’ar chomlec’h da-heul :',
	'forum_page_url' => '(Ma ra ho kemmennadenn anv eus ur pennad all war Internet pe eus ur bajenn warni muioc’h a ditouroù e c’hellit skrivañ amañ goude titl ar bajenn hag ar chomlec’h anezhi.)',
	'forum_permalink' => 'Liamm peurbad davet an addispleg',
	'forum_poste_par' => 'Kemennadenn kaset @parauteur@ da-heul ar pennad « @titre@ ».',
	'forum_poste_par_court' => 'Kemenadenn kaset@parauteur@.',
	'forum_poste_par_generique' => 'kemenadenn kaset@parauteur@ (@objet@ « @titre@ »).',
	'forum_qui_etes_vous' => '<b>Piv oc’h-hu ?</b> (Diret)',
	'forum_saisie_texte_info' => 'Ar furmskrid-mañ a zegemer ar berradennoù SPIP <code>[->url] {{gras}} {italique} <quote> <code></code> et le code HTML <code><q> <del> <ins></code>. Evit sevel rannbennadoù, n’eus nemet lezel linennoù goulo.',
	'forum_texte' => 'Testenn ho kemennadenn :',
	'forum_titre' => 'Titl',
	'forum_url' => 'Ho lec’hienn web',
	'forum_valider' => 'Kadarnaat an dibab-mañ',
	'forum_voir_avant' => 'Rakwelet ar gemennadenn a-raok kas anezhi',
	'forum_votre_email' => 'Ho postel :',
	'forum_votre_nom' => 'Hoc’h anv (pe lesanv) :',
	'forum_vous_enregistrer' => 'Evit kemer perzh er forom-mañ e rankit bezañ enrollet en a-raok.
  Trugarez da skrivañ amañ dindan an titouroù hiniennel zo bet roet deoc’h.
  Ma n’oc’h ket enrollet c’hoazh e rankit ',
	'forum_vous_inscrire' => 'en em enskrivañ.',

	// I
	'icone_bruler_message' => 'Merkañ evel Spam',
	'icone_bruler_messages' => 'Merkañ evel Spam',
	'icone_legitimer_message' => 'Merkañ evel aotreet',
	'icone_poster_message' => 'Kas ur gemennadenn',
	'icone_suivi_forum' => 'War ar forom foran : @nb_forums@ evezhiadenn',
	'icone_suivi_forums' => 'Heuliañ/merañ ar foromoù',
	'icone_supprimer_message' => 'Diverkañ ar gemennadenn-mañ',
	'icone_supprimer_messages' => 'Lemel ar c’hemenadennoù-mañ',
	'icone_valider_message' => 'Asantiñ d’ar gemennadenn-mañ',
	'icone_valider_messages' => 'Kadarnaat ar c’hemenadennoù-mañ',
	'icone_valider_repondre_message' => 'Kadarnaat ha respont d’ar gemenadenn-mañ',
	'info_1_message_forum' => '1 gemenadenn forum',
	'info_activer_forum_public' => '<i>Evit enaouiñ ar foromoù foran, dibabit un doare da habaskaat dre ziouer:</i>',
	'info_appliquer_choix_moderation' => 'Lakaat an dibab habaskaat-mañ e pleustr :',
	'info_config_forums_prive' => 'E lodenn brevez al lec’hienn e c’hellit ober gant meur a stumm forom disheñvel :',
	'info_config_forums_prive_admin' => 'Ur forom miret evit merourien al lec’hienn hepken :',
	'info_config_forums_prive_global' => 'Ur forom hollek, digor d’an holl skridaozerien :',
	'info_config_forums_prive_objets' => 'Ur forom dindan pep pennad, berrskrid, lec’hienn menegeret, h.a. :',
	'info_desactiver_forum_public' => 'Na implijout ar foromoù foran. Gallout a raint bezañ aotreet war ar pennadoù dibabet ganeoc’h, unan hag unan; ne’z aint ket en-dro er rubrikennoù, er berrskridoù, hag all...',
	'info_envoi_forum' => 'Kas ar foromoù da aozerien ar pennadoù',
	'info_fonctionnement_forum' => 'Mont en-dro ar forom :',
	'info_forcer_previsualisation_court' => 'Forsañ ar rak gwelet',
	'info_forcer_previsualisation_long' => 'Forsañ ar rakgwelet araok kas ar gemenadenn',
	'info_forums_liees_mot' => 'kemenadennoù ar forum liammet gant ar ger-mañ',
	'info_gauche_suivi_forum_2' => 'Pajenn <i>heuliañ ar foromoù</i> a dalvez da verañ ho lec’hienn (ha ket da dabutal pe da skridaozañ). Warni emañ an holl evezhiadennoù bet graet war foromoù al lec’hienn (lodennoù foran ha prevez), deoc’h da c’hallout o merañ.',
	'info_liens_syndiques_3' => 'forom',
	'info_liens_syndiques_4' => 'zo',
	'info_liens_syndiques_5' => 'forom',
	'info_liens_syndiques_6' => 'zo',
	'info_liens_syndiques_7' => 'o c’hortoz bezañ asantet',
	'info_liens_texte' => 'Liammoù e-barzh testenn ar gemenadenn',
	'info_liens_titre' => 'Liammoù e-barzh titl ar gemenadenn',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mont en-dro dre ziouer ar foromoù foran',
	'info_nb_messages_forum' => '@nb@ kemenadennoù forum',
	'info_option_email' => 'Pa vez kaset un evezhiadenn nevez gant ur gweladenner er forom diwar-benn ur pennad resis,
  e c’hell skridaozerien ar pennad bezañ kelaouet eus kement-se dre bostel.
  Ret eo deoc’h lavarout evit pep doare forom daoust ha fellout a ra deoc’h e vefe graet pe get.',
	'info_pas_de_forum' => 'forom ebet',
	'info_question_visiteur_ajout_document_forum' => 'M’hoc’h eus c’hoant da aotren ar weladennerien da stagañ restroù (skeudennoù, son, ...) ouzh o c’hemennadennoù war ar foromoù, neuze eo dav skrivañ amañ peseurt astennoù teulioù a vo aotreet war ar foromoù (da skouer : gif, png, jpg, mp3).',
	'info_question_visiteur_ajout_document_forum_format' => 'M’hoc’h eus c’hoant da aotren an holl seurtoù restroù en deus SPIP fiziañs enno, neuze lakait ur steredennig. Evit aotren tra ebet, na lakait netra !',
	'info_selectionner_message' => 'Dibab ar c’hemenadennoù :',
	'interface_formulaire' => 'Etrefas furmskrid',
	'interface_onglets' => 'Etrefas gant ivinennoù',
	'item_activer_forum_administrateur' => 'Gweredekaat forom ar verourien',
	'item_config_forums_prive_global' => 'Gweredekaat forom ar skridaozerien',
	'item_config_forums_prive_objets' => 'Gweredekaat ar foromoù-se',
	'item_desactiver_forum_administrateur' => 'Diweredekaat forom ar verourien',
	'item_non_config_forums_prive_global' => 'Diweredekaat forom ar skridaozerien',
	'item_non_config_forums_prive_objets' => 'Diweredekaat ar foromoù-mañ',

	// L
	'label_selectionner' => 'Diuz :',
	'lien_reponse_article' => 'Respont d’ar pennad',
	'lien_reponse_breve_2' => 'Respont d’ar berrskrid',
	'lien_reponse_message' => 'Respont d’ar gemenadenn',
	'lien_reponse_rubrique' => 'Respont d’ar rubrikenn',
	'lien_reponse_site_reference' => 'Respont d’al lec’hienn daveennet :',
	'lien_vider_selection' => 'Goulloiñ an dibab',

	// M
	'messages_aucun' => 'Hini ebet',
	'messages_meme_auteur' => 'Holl kemenadennoù an aozer',
	'messages_meme_email' => 'holl kemenadennoù ar postel-mañ',
	'messages_meme_ip' => 'holl kemenadennoù an IP-mañ',
	'messages_off' => 'Bet lemet',
	'messages_perso' => 'Personel',
	'messages_privadm' => 'Merourien',
	'messages_prive' => 'Prevez',
	'messages_privoff' => 'Bet lemet kuit',
	'messages_privrac' => 'hollek',
	'messages_prop' => 'Kinniget',
	'messages_publie' => 'Embannet',
	'messages_spam' => 'Spam',
	'messages_tous' => 'An holl',

	// O
	'onglet_messages_internes' => 'Kemennadennoù diabarzh',
	'onglet_messages_publics' => 'Kemennadennoù foran',
	'onglet_messages_vide' => 'kemennadennoù hep testenn',

	// R
	'repondre_message' => 'Respont d’ar gemennadenn-mañ',

	// S
	'statut_off' => 'Bet lemet kuit',
	'statut_original' => 'orin',
	'statut_prop' => 'Kinniget',
	'statut_publie' => 'Enbannet',
	'statut_spam' => 'Spam',

	// T
	'text_article_propose_publication_forum' => 'Gallout a rit reiñ hoc’h ali war ar forom stag ouzh ar pennad-mañ (e traoñ ar bajenn)',
	'texte_en_cours_validation' => 'Ar pennadoù-skrid, ar skridoù-berr, ar foromoù amañ dindan a zo kinniget evit an embann',
	'texte_en_cours_validation_forum' => 'Gallout a rit reiñ hoc’h ali er foromoù stag outo.',
	'texte_messages_publics' => 'Kemenadennoù foran war :',
	'titre_cadre_forum_administrateur' => 'Forom prevez ar verourien',
	'titre_cadre_forum_interne' => 'Forom diabarzh',
	'titre_config_forums_prive' => 'Foromoù al lodenn brevez',
	'titre_forum' => 'Forom',
	'titre_forum_suivi' => 'Heuliañ ar foromoù',
	'titre_page_forum_suivi' => 'Heuliañ ar foromoù',
	'titre_selection_action' => 'Diuz',
	'tout_voir' => 'Gwelet an holl gemenadennoù',

	// V
	'voir_messages_objet' => 'Gwelet ar c’hemenadennoù',
];

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=br
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_message_forum' => 'Kemenadenn forom ebet',

	// B
	'bouton_radio_articles_futurs' => 'er pennadoù da zont hepken (oberiadenn ebet en diaz titouroù)',
	'bouton_radio_articles_tous' => 'en holl pennadoù.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'en holl bennadoù n’eo ket bet diweredekaet o forom',
	'bouton_radio_enregistrement_obligatoire' => 'Enrolladenn ret (a-raok gallout kemer perzh e rank an implijerien en em enrollañ en ur reiñ o chomlec’h postel).', # MODIF
	'bouton_radio_moderation_priori' => 'Gwiriañ a-raok embann (diskouez a reer ar c’hemennadennoù ur wech lennet hag aotreet gant ar verourien hepken).', # MODIF
	'bouton_radio_modere_abonnement' => 'war goumanant',
	'bouton_radio_modere_posteriori' => 'gwiriañ goude an embann',
	'bouton_radio_modere_priori' => 'gwiriañ a-raok embann',
	'bouton_radio_publication_immediate' => 'Embann ar c’hemennadennoù kerkent (embannet e vez ar c’hemennadennoù diouzhtu goude bezañ bet skrivet, war-lerc’h e c’hellont bezañ diverket gant ar verourien).', # MODIF

	// D
	'documents_interdits_forum' => 'Teulioù difennet er forom',

	// E
	'erreur_enregistrement_message' => 'Ne ket bet posubl enrolliñ ho kemenadenn ablamour d’un diaesamant teknikel',
	'extensions_autorisees' => 'Astennoù aotreet',
	'extensions_autorisees_toutes' => 'holl',

	// F
	'form_pet_message_commentaire' => 'Ur gemennadenn, un evezhiadenn ?',
	'forum' => 'Forom',
	'forum_acces_refuse' => 'N’oc’h ket aotreet da vont war ar foromoù-mañ ken .',
	'forum_attention_dix_caracteres' => '<b>Diwallit !</b> Dek arouezenn d’an nebeutañ a rank bezañ en ho kemennadenn.',
	'forum_attention_message_non_poste' => 'Taolit evezh, n’ho peus ket kaset ho kemenadenn !',
	'forum_attention_nb_caracteres_mini' => '<b>Taolit evezh !</b> ho kemenadenn a rank bezañ henni @min@ letrenn.',
	'forum_attention_trois_caracteres' => '<b>Diwallit !</b> Teir arouezenn d’an nebeutañ a rank bezañ en ho titl.',
	'forum_attention_trop_caracteres' => '<b>Diwallit !</b> re hir eo ho kemennadenn (@compte@ arouez) : arabat e vefe ouzhpenn @max@ arouezenn enni evit gallout bezañ kaset.',
	'forum_avez_selectionne' => 'Diuzet hoc’h eus :',
	'forum_cliquer_retour' => 'Klikit <a href=\'@retour_forum@\'>amañ</a> evit kenderc’hel.',
	'forum_envoyer' => 'Kas',
	'forum_forum' => 'forom',
	'forum_info_modere' => 'Habaskaet eo ar forom-mañ a-raok embann ar pennadoù : ne vo ket gwelet ho kemennadenn a-raok na vefe lennet hag asantet gant unan eus merourien al lec’hienn.', # MODIF
	'forum_lien_hyper' => '<b>liamm gourskrid</b> (Diret)',
	'forum_message' => 'Ho kemenadenn',
	'forum_message_definitif' => 'Kemennadenn echu : kas d’al lec’hienn',
	'forum_message_trop_long' => 'Re hir eo ho kemennadenn. 20000 arouezenn a c’heller lakaat d’ar muiañ.',
	'forum_ne_repondez_pas' => 'Na respontit ket d’ar postel-mañ, met war ar forom, d’ar chomlec’h da-heul :',
	'forum_page_url' => '(Ma ra ho kemmennadenn anv eus ur pennad all war Internet pe eus ur bajenn warni muioc’h a ditouroù e c’hellit skrivañ amañ goude titl ar bajenn hag ar chomlec’h anezhi.)',
	'forum_permalink' => 'Liamm peurbad davet an addispleg',
	'forum_poste_par' => 'Kemennadenn kaset @parauteur@ da-heul ar pennad « @titre@ ».',
	'forum_poste_par_court' => 'Kemenadenn kaset@parauteur@.',
	'forum_poste_par_generique' => 'kemenadenn kaset@parauteur@ (@objet@ « @titre@ »).',
	'forum_qui_etes_vous' => '<b>Piv oc’h-hu ?</b> (Diret)',
	'forum_saisie_texte_info' => 'Ar furmskrid-mañ a zegemer ar berradennoù SPIP <code>[->url] {{gras}} {italique} <quote> <code></code> et le code HTML <code><q> <del> <ins></code>. Evit sevel rannbennadoù, n’eus nemet lezel linennoù goulo.',
	'forum_texte' => 'Testenn ho kemennadenn :',
	'forum_titre' => 'Titl',
	'forum_url' => 'Ho lec’hienn web',
	'forum_valider' => 'Kadarnaat an dibab-mañ',
	'forum_voir_avant' => 'Rakwelet ar gemennadenn a-raok kas anezhi',
	'forum_votre_email' => 'Ho postel :',
	'forum_votre_nom' => 'Hoc’h anv (pe lesanv) :',
	'forum_vous_enregistrer' => 'Evit kemer perzh er forom-mañ e rankit bezañ enrollet en a-raok.
  Trugarez da skrivañ amañ dindan an titouroù hiniennel zo bet roet deoc’h.
  Ma n’oc’h ket enrollet c’hoazh e rankit ',
	'forum_vous_inscrire' => 'en em enskrivañ.',

	// I
	'icone_bruler_message' => 'Merkañ evel Spam',
	'icone_bruler_messages' => 'Merkañ evel Spam',
	'icone_legitimer_message' => 'Merkañ evel aotreet',
	'icone_poster_message' => 'Kas ur gemennadenn',
	'icone_suivi_forum' => 'War ar forom foran : @nb_forums@ evezhiadenn',
	'icone_suivi_forums' => 'Heuliañ/merañ ar foromoù',
	'icone_supprimer_message' => 'Diverkañ ar gemennadenn-mañ',
	'icone_supprimer_messages' => 'Lemel ar c’hemenadennoù-mañ',
	'icone_valider_message' => 'Asantiñ d’ar gemennadenn-mañ',
	'icone_valider_messages' => 'Kadarnaat ar c’hemenadennoù-mañ',
	'icone_valider_repondre_message' => 'Kadarnaat ha respont d’ar gemenadenn-mañ',
	'info_1_message_forum' => '1 gemenadenn forum',
	'info_activer_forum_public' => '<i>Evit enaouiñ ar foromoù foran, dibabit un doare da habaskaat dre ziouer:</i>',
	'info_appliquer_choix_moderation' => 'Lakaat an dibab habaskaat-mañ e pleustr :',
	'info_config_forums_prive' => 'E lodenn brevez al lec’hienn e c’hellit ober gant meur a stumm forom disheñvel :',
	'info_config_forums_prive_admin' => 'Ur forom miret evit merourien al lec’hienn hepken :', # MODIF
	'info_config_forums_prive_global' => 'Ur forom hollek, digor d’an holl skridaozerien :', # MODIF
	'info_config_forums_prive_objets' => 'Ur forom dindan pep pennad, berrskrid, lec’hienn menegeret, h.a. :',
	'info_desactiver_forum_public' => 'Na implijout ar foromoù foran. Gallout a raint bezañ aotreet war ar pennadoù dibabet ganeoc’h, unan hag unan; ne’z aint ket en-dro er rubrikennoù, er berrskridoù, hag all...',
	'info_envoi_forum' => 'Kas ar foromoù da aozerien ar pennadoù', # MODIF
	'info_fonctionnement_forum' => 'Mont en-dro ar forom :',
	'info_forcer_previsualisation_court' => 'Forsañ ar rak gwelet',
	'info_forcer_previsualisation_long' => 'Forsañ ar rakgwelet araok kas ar gemenadenn',
	'info_forums_liees_mot' => 'kemenadennoù ar forum liammet gant ar ger-mañ',
	'info_gauche_suivi_forum_2' => 'Pajenn <i>heuliañ ar foromoù</i> a dalvez da verañ ho lec’hienn (ha ket da dabutal pe da skridaozañ). Warni emañ an holl evezhiadennoù bet graet war foromoù al lec’hienn (lodennoù foran ha prevez), deoc’h da c’hallout o merañ.',
	'info_liens_syndiques_3' => 'forom',
	'info_liens_syndiques_4' => 'zo',
	'info_liens_syndiques_5' => 'forom',
	'info_liens_syndiques_6' => 'zo',
	'info_liens_syndiques_7' => 'o c’hortoz bezañ asantet',
	'info_liens_texte' => 'Liammoù e-barzh testenn ar gemenadenn',
	'info_liens_titre' => 'Liammoù e-barzh titl ar gemenadenn',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mont en-dro dre ziouer ar foromoù foran',
	'info_nb_messages_forum' => '@nb@ kemenadennoù forum',
	'info_option_email' => 'Pa vez kaset un evezhiadenn nevez gant ur gweladenner er forom diwar-benn ur pennad resis,
  e c’hell skridaozerien ar pennad bezañ kelaouet eus kement-se dre bostel.
  Ret eo deoc’h lavarout evit pep doare forom daoust ha fellout a ra deoc’h e vefe graet pe get.', # MODIF
	'info_pas_de_forum' => 'forom ebet',
	'info_question_visiteur_ajout_document_forum' => 'M’hoc’h eus c’hoant da aotren ar weladennerien da stagañ restroù (skeudennoù, son, ...) ouzh o c’hemennadennoù war ar foromoù, neuze eo dav skrivañ amañ peseurt astennoù teulioù a vo aotreet war ar foromoù (da skouer : gif, png, jpg, mp3).', # MODIF
	'info_question_visiteur_ajout_document_forum_format' => 'M’hoc’h eus c’hoant da aotren an holl seurtoù restroù en deus SPIP fiziañs enno, neuze lakait ur steredennig. Evit aotren tra ebet, na lakait netra !',
	'info_selectionner_message' => 'Dibab ar c’hemenadennoù :',
	'interface_formulaire' => 'Etrefas furmskrid',
	'interface_onglets' => 'Etrefas gant ivinennoù',
	'item_activer_forum_administrateur' => 'Gweredekaat forom ar verourien', # MODIF
	'item_config_forums_prive_global' => 'Gweredekaat forom ar skridaozerien', # MODIF
	'item_config_forums_prive_objets' => 'Gweredekaat ar foromoù-se',
	'item_desactiver_forum_administrateur' => 'Diweredekaat forom ar verourien', # MODIF
	'item_non_config_forums_prive_global' => 'Diweredekaat forom ar skridaozerien', # MODIF
	'item_non_config_forums_prive_objets' => 'Diweredekaat ar foromoù-mañ',

	// L
	'label_selectionner' => 'Diuz :',
	'lien_reponse_article' => 'Respont d’ar pennad',
	'lien_reponse_breve_2' => 'Respont d’ar berrskrid',
	'lien_reponse_message' => 'Respont d’ar gemenadenn',
	'lien_reponse_rubrique' => 'Respont d’ar rubrikenn',
	'lien_reponse_site_reference' => 'Respont d’al lec’hienn daveennet :',
	'lien_vider_selection' => 'Goulloiñ an dibab',

	// M
	'messages_aucun' => 'Hini ebet',
	'messages_meme_auteur' => 'Holl kemenadennoù an aozer', # MODIF
	'messages_meme_email' => 'holl kemenadennoù ar postel-mañ',
	'messages_meme_ip' => 'holl kemenadennoù an IP-mañ',
	'messages_off' => 'Bet lemet',
	'messages_perso' => 'Personel',
	'messages_privadm' => 'Merourien', # MODIF
	'messages_prive' => 'Prevez',
	'messages_privoff' => 'Bet lemet kuit',
	'messages_privrac' => 'hollek',
	'messages_prop' => 'Kinniget',
	'messages_publie' => 'Embannet',
	'messages_spam' => 'Spam',
	'messages_tous' => 'An holl',

	// O
	'onglet_messages_internes' => 'Kemennadennoù diabarzh',
	'onglet_messages_publics' => 'Kemennadennoù foran',
	'onglet_messages_vide' => 'kemennadennoù hep testenn',

	// R
	'repondre_message' => 'Respont d’ar gemennadenn-mañ',

	// S
	'statut_off' => 'Bet lemet kuit',
	'statut_original' => 'orin',
	'statut_prop' => 'Kinniget',
	'statut_publie' => 'Enbannet',
	'statut_spam' => 'Spam',

	// T
	'text_article_propose_publication_forum' => 'Gallout a rit reiñ hoc’h ali war ar forom stag ouzh ar pennad-mañ (e traoñ ar bajenn)',
	'texte_en_cours_validation' => 'Ar pennadoù-skrid, ar skridoù-berr, ar foromoù amañ dindan a zo kinniget evit an embann',
	'texte_en_cours_validation_forum' => 'Gallout a rit reiñ hoc’h ali er foromoù stag outo.',
	'texte_messages_publics' => 'Kemenadennoù foran war :',
	'titre_cadre_forum_administrateur' => 'Forom prevez ar verourien', # MODIF
	'titre_cadre_forum_interne' => 'Forom diabarzh',
	'titre_config_forums_prive' => 'Foromoù al lodenn brevez',
	'titre_forum' => 'Forom',
	'titre_forum_suivi' => 'Heuliañ ar foromoù',
	'titre_page_forum_suivi' => 'Heuliañ ar foromoù',
	'titre_selection_action' => 'Diuz',
	'tout_voir' => 'Gwelet an holl gemenadennoù',

	// V
	'voir_messages_objet' => 'Gwelet ar c’hemenadennoù',
];
